@@ -4,7 +4,7 @@
 __author__ = 'Jeff Quast <contact@jeffquast.com>'
 __license__ = 'MIT'
 
-__all__ = ['init_sequence_patterns', 'Sequence', 'SequenceTextWrapper']
+__all__ = ('init_sequence_patterns', 'Sequence', 'SequenceTextWrapper',)
 
 # built-ins
 import functools
@@ -14,12 +14,15 @@ import math
 import sys
 import re
 
+# local
+from ._binterms import binary_terminals as _BINTERM_UNSUPPORTED
+
 # 3rd-party
 import wcwidth  # https://github.com/jquast/wcwidth
 
-_BINTERM_UNSUPPORTED = ('kermit', 'avatar')
-_BINTERM_UNSUPPORTED_MSG = ('sequence-awareness for terminals emitting '
-                            'binary-packed capabilities are not supported.')
+_BINTERM_UNSUPPORTED_MSG = (
+    u"Terminal kind {0!r} contains binary-packed capabilities, blessed "
+    u"is likely to fail to measure the length of its sequences.")
 
 if sys.version_info[0] == 3:
     text_type = str
@@ -100,7 +103,7 @@ def get_movement_sequence_patterns(term):
         re.escape(term.rc),
         # clear_screen: clear screen and home cursor
         re.escape(term.clear),
-        # cursor_up: Up one line
+        # enter/exit_fullscreen: switch to alternate screen buffer
         re.escape(term.enter_fullscreen),
         re.escape(term.exit_fullscreen),
         # forward cursor
@@ -263,7 +266,7 @@ def init_sequence_patterns(term):
     printable length of a string.
     """
     if term.kind in _BINTERM_UNSUPPORTED:
-        warnings.warn(_BINTERM_UNSUPPORTED_MSG)
+        warnings.warn(_BINTERM_UNSUPPORTED_MSG.format(term.kind))
 
     # Build will_move, a list of terminal capabilities that have
     # indeterminate effects on the terminal cursor position.
@@ -322,9 +325,6 @@ def init_sequence_patterns(term):
 class SequenceTextWrapper(textwrap.TextWrapper):
     def __init__(self, width, term, **kwargs):
         self.term = term
-        assert kwargs.get('break_long_words', False) is False, (
-            'break_long_words is not sequence-safe')
-        kwargs['break_long_words'] = False
         textwrap.TextWrapper.__init__(self, width, **kwargs)
 
     def _wrap_chunks(self, chunks):
@@ -369,6 +369,58 @@ class SequenceTextWrapper(textwrap.TextWrapper):
                 lines.append(indent + u''.join(cur_line))
         return lines
 
+    def _handle_long_word(self, reversed_chunks, cur_line, cur_len, width):
+        """_handle_long_word(chunks : [string],
+                             cur_line : [string],
+                             cur_len : int, width : int)
+
+        Handle a chunk of text (most likely a word, not whitespace) that
+        is too long to fit in any line.
+        """
+        # Figure out when indent is larger than the specified width, and make
+        # sure at least one character is stripped off on every pass
+        if width < 1:
+            space_left = 1
+        else:
+            space_left = width - cur_len
+
+        # If we're allowed to break long words, then do so: put as much
+        # of the next chunk onto the current line as will fit.
+        if self.break_long_words:
+            term = self.term
+            chunk = reversed_chunks[-1]
+            nxt = 0
+            for idx in range(0, len(chunk)):
+                if idx == nxt:
+                    # at sequence, point beyond it,
+                    nxt = idx + measure_length(chunk[idx:], term)
+                if nxt <= idx:
+                    # point beyond next sequence, if any,
+                    # otherwise point to next character
+                    nxt = idx + measure_length(chunk[idx:], term) + 1
+                if Sequence(chunk[:nxt], term).length() > space_left:
+                    break
+            else:
+                # our text ends with a sequence, such as in text
+                # u'!\x1b(B\x1b[m', set index at at end (nxt)
+                idx = nxt
+
+            cur_line.append(chunk[:idx])
+            reversed_chunks[-1] = chunk[idx:]
+
+        # Otherwise, we have to preserve the long word intact.  Only add
+        # it to the current line if there's nothing already there --
+        # that minimizes how much we violate the width constraint.
+        elif not cur_line:
+            cur_line.append(reversed_chunks.pop())
+
+        # If we're not allowed to break long words, and there's already
+        # text on the current line, do nothing.  Next time through the
+        # main loop of _wrap_chunks(), we'll wind up here again, but
+        # cur_len will be zero, so the next line will be entirely
+        # devoted to the long word that we can't handle right now.
+
+
 SequenceTextWrapper.__doc__ = textwrap.TextWrapper.__doc__
 
 
