@@ -3,9 +3,11 @@
 # std
 from __future__ import with_statement
 import contextlib
+import subprocess
 import functools
 import traceback
 import termios
+import random
 import codecs
 import curses
 import sys
@@ -27,16 +29,25 @@ TestTerminal = functools.partial(Terminal, kind='xterm-256color')
 SEND_SEMAPHORE = SEMAPHORE = b'SEMAPHORE\n'
 RECV_SEMAPHORE = b'SEMAPHORE\r\n'
 all_xterms_params = ['xterm', 'xterm-256color']
-all_terms_params = ['screen', 'vt220', 'rxvt', 'cons25', 'linux', 'ansi']
-binpacked_terminal_params = ['avatar', 'kermit']
 many_lines_params = [30, 100]
-many_columns_params = [10, 100]
-if os.environ.get('TRAVIS', None) is None:
-    # TRAVIS-CI has a limited type of terminals, the others ...
-    all_terms_params.extend(['avatar', 'kermit', 'dtterm', 'wyse520',
-                             'minix', 'eterm', 'aixterm', 'putty'])
-all_standard_terms_params = (set(all_terms_params) -
-                             set(binpacked_terminal_params))
+many_columns_params = [1, 10]
+from blessed._binterms import binary_terminals
+default_all_terms = ['screen', 'vt220', 'rxvt', 'cons25', 'linux', 'ansi']
+if os.environ.get('TEST_ALLTERMS'):
+    try:
+        available_terms = [
+            _term.split(None, 1)[0] for _term in
+            subprocess.Popen(('toe', '-a'),
+                             stdout=subprocess.PIPE,
+                             close_fds=True)
+            .communicate()[0].splitlines()]
+    except OSError:
+        all_terms_params = default_all_terms
+else:
+    available_terms = default_all_terms
+all_terms_params = list(set(available_terms) - (
+    set(binary_terminals) if not os.environ.get('TEST_BINTERMS')
+    else set())) or default_all_terms
 
 
 class as_subprocess(object):
@@ -174,7 +185,10 @@ def echo_off(fd):
 
 def unicode_cap(cap):
     """Return the result of ``tigetstr`` except as Unicode."""
-    val = curses.tigetstr(cap)
+    try:
+        val = curses.tigetstr(cap)
+    except curses.error:
+        val = None
     if val:
         return val.decode('latin1')
     return u''
@@ -182,15 +196,21 @@ def unicode_cap(cap):
 
 def unicode_parm(cap, *parms):
     """Return the result of ``tparm(tigetstr())`` except as Unicode."""
-    cap = curses.tigetstr(cap)
+    try:
+        cap = curses.tigetstr(cap)
+    except curses.error:
+        cap = None
     if cap:
-        val = curses.tparm(cap, *parms)
+        try:
+            val = curses.tparm(cap, *parms)
+        except curses.error:
+            val = None
         if val:
             return val.decode('latin1')
     return u''
 
 
-@pytest.fixture(params=binpacked_terminal_params)
+@pytest.fixture(params=binary_terminals)
 def unsupported_sequence_terminals(request):
     """Terminals that emit warnings for unsupported sequence-awareness."""
     return request.param
@@ -208,12 +228,6 @@ def all_terms(request):
     return request.param
 
 
-@pytest.fixture(params=all_standard_terms_params)
-def all_standard_terms(request):
-    """Common kind values for all kinds of terminals (except binary-packed)."""
-    return request.param
-
-
 @pytest.fixture(params=many_lines_params)
 def many_lines(request):
     """Various number of lines for screen height."""
